package com.ruoyi.system.controller;

import java.util.ArrayList;
import java.util.List;
import javax.servlet.http.HttpServletResponse;

import com.ruoyi.common.annotation.Anonymous;
import com.ruoyi.common.utils.StringUtils;
import com.ruoyi.system.domain.Model;
import com.ruoyi.web.PublicUrlDto;
import org.springframework.security.access.prepost.PreAuthorize;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.GetMapping;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.PutMapping;
import org.springframework.web.bind.annotation.DeleteMapping;
import org.springframework.web.bind.annotation.PathVariable;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RestController;
import com.ruoyi.common.annotation.Log;
import com.ruoyi.common.core.controller.BaseController;
import com.ruoyi.common.core.domain.AjaxResult;
import com.ruoyi.common.enums.BusinessType;
import com.ruoyi.system.domain.Bs;
import com.ruoyi.system.service.IBsService;
import com.ruoyi.common.utils.poi.ExcelUtil;
import com.ruoyi.common.core.page.TableDataInfo;

/**
 * 标识管理Controller
 * 
 * @author 胡懿
 * @date 2025-03-25
 */
@RestController
@RequestMapping("/system/bs")
public class BsController extends BaseController
{
    @Autowired
    private IBsService bsService;

    /**
     * 查询标识管理列表
     */
    @PreAuthorize("@ss.hasPermi('system:bs:list')")
    @GetMapping("/list")
    public TableDataInfo list(Bs bs)
    {
        startPage();
        List<Bs> list = bsService.selectBsList(bs);
        return getDataTable(list);
    }

    /**
     * 导出标识管理列表
     */
    @PreAuthorize("@ss.hasPermi('system:bs:export')")
    @Log(title = "标识管理", businessType = BusinessType.EXPORT)
    @PostMapping("/export")
    public void export(HttpServletResponse response, Bs bs)
    {
        List<Bs> list = bsService.selectBsList(bs);
        ExcelUtil<Bs> util = new ExcelUtil<Bs>(Bs.class);
        util.exportExcel(response, list, "标识管理数据");
    }

    /**
     * 获取标识管理详细信息
     */
    @PreAuthorize("@ss.hasPermi('system:bs:query')")
    @GetMapping(value = "/{id}")
    public AjaxResult getInfo(@PathVariable("id") Long id)
    {
        return success(bsService.selectBsById(id));
    }

    /**
     * 新增标识管理
     */
    @PreAuthorize("@ss.hasPermi('system:bs:add')")
    @Log(title = "标识管理", businessType = BusinessType.INSERT)
    @PostMapping
    public AjaxResult add(@RequestBody Bs bs)
    {
        return toAjax(bsService.insertBs(bs));
    }

    /**
     * 修改标识管理
     */
    @PreAuthorize("@ss.hasPermi('system:bs:edit')")
    @Log(title = "标识管理", businessType = BusinessType.UPDATE)
    @PutMapping
    public AjaxResult edit(@RequestBody Bs bs)
    {
        return toAjax(bsService.updateBs(bs));
    }

    /**
     * 删除标识管理
     */
    @PreAuthorize("@ss.hasPermi('system:bs:remove')")
    @Log(title = "标识管理", businessType = BusinessType.DELETE)
	@DeleteMapping("/{ids}")
    public AjaxResult remove(@PathVariable Long[] ids)
    {
        return toAjax(bsService.deleteBsByIds(ids));
    }


    @Anonymous
    @GetMapping("/publicList")
    public TableDataInfo publicList(Bs bs)
    {
        startPage();
        List<Bs> list = bsService.publicList(bs);
        return getDataTable(list);
    }

    @GetMapping("/getPublicList")
    public TableDataInfo getPublicList(PublicUrlDto publicUrlDto)
    {
        if (StringUtils.isNotBlank(publicUrlDto.getUrl())) {
            return bsService.getPublicList(publicUrlDto.getUrl(), publicUrlDto.getBs(), publicUrlDto.getPageSize(), publicUrlDto.getPageNum());
        } else {
            return getDataTable(new ArrayList<Bs>());
        }

    }
}
