package com.ruoyi.system.controller;

import java.util.List;
import javax.servlet.http.HttpServletResponse;
import org.springframework.security.access.prepost.PreAuthorize;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.GetMapping;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.PutMapping;
import org.springframework.web.bind.annotation.DeleteMapping;
import org.springframework.web.bind.annotation.PathVariable;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RestController;
import com.ruoyi.common.annotation.Log;
import com.ruoyi.common.core.controller.BaseController;
import com.ruoyi.common.core.domain.AjaxResult;
import com.ruoyi.common.enums.BusinessType;
import com.ruoyi.system.domain.Prefix;
import com.ruoyi.system.service.IPrefixService;
import com.ruoyi.common.utils.poi.ExcelUtil;
import com.ruoyi.common.core.page.TableDataInfo;

/**
 * 本公司信息Controller
 * 
 * @author 胡懿
 * @date 2025-03-25
 */
@RestController
@RequestMapping("/system/prefix")
public class PrefixController extends BaseController
{
    @Autowired
    private IPrefixService prefixService;

    /**
     * 查询本公司信息列表
     */
    @PreAuthorize("@ss.hasPermi('system:prefix:list')")
    @GetMapping("/list")
    public TableDataInfo list(Prefix prefix)
    {
        startPage();
        List<Prefix> list = prefixService.selectPrefixList(prefix);
        return getDataTable(list);
    }

    /**
     * 导出本公司信息列表
     */
    @PreAuthorize("@ss.hasPermi('system:prefix:export')")
    @Log(title = "本公司信息", businessType = BusinessType.EXPORT)
    @PostMapping("/export")
    public void export(HttpServletResponse response, Prefix prefix)
    {
        List<Prefix> list = prefixService.selectPrefixList(prefix);
        ExcelUtil<Prefix> util = new ExcelUtil<Prefix>(Prefix.class);
        util.exportExcel(response, list, "本公司信息数据");
    }

    /**
     * 获取本公司信息详细信息
     */
    @PreAuthorize("@ss.hasPermi('system:prefix:query')")
    @GetMapping(value = "/{id}")
    public AjaxResult getInfo(@PathVariable("id") Long id)
    {
        return success(prefixService.selectPrefixById(id));
    }

    /**
     * 新增本公司信息
     */
    @PreAuthorize("@ss.hasPermi('system:prefix:add')")
    @Log(title = "本公司信息", businessType = BusinessType.INSERT)
    @PostMapping
    public AjaxResult add(@RequestBody Prefix prefix)
    {
        return toAjax(prefixService.insertPrefix(prefix));
    }

    /**
     * 修改本公司信息
     */
    @PreAuthorize("@ss.hasPermi('system:prefix:edit')")
    @Log(title = "本公司信息", businessType = BusinessType.UPDATE)
    @PutMapping
    public AjaxResult edit(@RequestBody Prefix prefix)
    {
        return toAjax(prefixService.updatePrefix(prefix));
    }

    /**
     * 删除本公司信息
     */
    @PreAuthorize("@ss.hasPermi('system:prefix:remove')")
    @Log(title = "本公司信息", businessType = BusinessType.DELETE)
	@DeleteMapping("/{ids}")
    public AjaxResult remove(@PathVariable Long[] ids)
    {
        return toAjax(prefixService.deletePrefixByIds(ids));
    }
}
