package com.ruoyi.system.utils;

import com.alibaba.fastjson2.JSONObject;
import org.apache.commons.math3.analysis.function.Sin;
import org.springframework.http.*;
import org.springframework.web.client.RestTemplate;

import java.util.Base64;

public class BsjxUtils {

    public static String getToken(String username, String password) {
        RestTemplate restTemplate = new RestTemplate();
        BsjxUPBody bsjxUPBody = new BsjxUPBody();
        bsjxUPBody.setUsername(username);
        bsjxUPBody.setPassword(password);


        String url = "https://snms.sxlq.com/identity/token";
        String response = restTemplate.postForObject(url, bsjxUPBody, String.class);

        JSONObject jsonObject =  JSONObject.parseObject(response);
        String message = (String) jsonObject.get("message");
        Integer status = (Integer) jsonObject.get("status");
        if (null != status && -2 != status) {
            JSONObject data = (JSONObject) jsonObject.get("data");
            String token = (String) data.get("token");
            return token;
        } else {
            return "";
        }
    }

    public static String getDataTemplate(String token, String prefix, String modelType) {
        RestTemplate restTemplate = new RestTemplate();
        String url = "https://snms.sxlq.com/snms/api/v3/template?prefix=" + prefix + "&version=" + modelType;

        HttpHeaders headers = new HttpHeaders();
        headers.set("Authorization", "Bearer " + token);
        headers.setContentType(MediaType.APPLICATION_JSON);
        HttpEntity<String> entity = new HttpEntity<>("parameters", headers);

        ResponseEntity<String> response = restTemplate.exchange(
                url,
                HttpMethod.GET,
                entity,
                String.class);
        String body = response.getBody();
        JSONObject jsonObject =  JSONObject.parseObject(body);
        Integer status = (Integer) jsonObject.get("status");
        if (null != status && -2 != status) {
            JSONObject data = (JSONObject) jsonObject.get("data");
            return data.toString();
        } else {
            return "";
        }
    }

    /**
     * 查询标识
     * @param token
     * @param handle
     * @return
     */
    public static SignInfo getSign(String token, String prefix, String handle) {
        RestTemplate restTemplate = new RestTemplate();
        String url = "https://snms.sxlq.com/identityv2/data/detail?prefix=" + prefix + "&handle=" + handle;

        HttpHeaders headers = new HttpHeaders();
        headers.set("Authorization", "Bearer " + token);
        headers.setContentType(MediaType.APPLICATION_JSON);
        HttpEntity<String> entity = new HttpEntity<>("parameters", headers);

        ResponseEntity<String> response = restTemplate.exchange(
                url,
                HttpMethod.GET,
                entity,
                String.class);
        String body = response.getBody();
        JSONObject jsonObject =  JSONObject.parseObject(body);
        Integer status = (Integer) jsonObject.get("status");
        if (null != status && -2 != status) {
            JSONObject data = (JSONObject) jsonObject.get("data");
            System.out.println(data.toString());
            SignInfo signInfo = JSONObject.parseObject(data.toString(), SignInfo.class);
            return signInfo;
        } else {
            return null;
        }
    }

    /**
     * 添加标识
     * @param signAddInfo
     * @return
     */
    public static boolean addSign(String token, SignAddInfo signAddInfo) {

        RestTemplate restTemplate = new RestTemplate();
        String url = "https://snms.sxlq.com/identityv2/data";

        HttpHeaders headers = new HttpHeaders();
        headers.set("Authorization", "Bearer " + token);
        headers.setContentType(MediaType.APPLICATION_JSON);
        HttpEntity<String> entity = new HttpEntity<>(JSONObject.toJSONString(signAddInfo), headers);


        ResponseEntity<String> response = restTemplate.exchange(
                url,
                HttpMethod.POST,
                entity,
                String.class);
        String body = response.getBody();
        System.out.println(body);
        JSONObject jsonObject =  JSONObject.parseObject(body);
        Integer status = (Integer) jsonObject.get("status");
        if (null != status && -2 != status) {
            return true;
        } else {
            return false;
        }
    }

    /**
     * 修改标识
     * @param signAddInfo
     * @return
     */
    public static boolean updateSign(String token, SignAddInfo signAddInfo) {
        RestTemplate restTemplate = new RestTemplate();
        String url = "https://snms.sxlq.com/identityv2/data";

        HttpHeaders headers = new HttpHeaders();
        headers.set("Authorization", "Bearer " + token);
        headers.setContentType(MediaType.APPLICATION_JSON);
        HttpEntity<String> entity = new HttpEntity<>(JSONObject.toJSONString(signAddInfo), headers);


        ResponseEntity<String> response = restTemplate.exchange(
                url,
                HttpMethod.PUT,
                entity,
                String.class);
        String body = response.getBody();
        System.out.println(body);
        JSONObject jsonObject =  JSONObject.parseObject(body);
        Integer status = (Integer) jsonObject.get("status");
        if (null != status && -2 != status) {
            return true;
        } else {
            return false;
        }
    }

    /**
     * 删除标识
     * @param signAddInfo
     * @return
     */
    public static boolean deleteSign(String token, SignAddInfo signAddInfo) {
        RestTemplate restTemplate = new RestTemplate();
        String url = "https://snms.sxlq.com/identityv2/data";

        HttpHeaders headers = new HttpHeaders();
        headers.set("Authorization", "Bearer " + token);
        headers.setContentType(MediaType.APPLICATION_JSON);
        HttpEntity<String> entity = new HttpEntity<>(JSONObject.toJSONString(signAddInfo), headers);


        ResponseEntity<String> response = restTemplate.exchange(
                url,
                HttpMethod.DELETE,
                entity,
                String.class);
        String body = response.getBody();
        System.out.println(body);
        JSONObject jsonObject =  JSONObject.parseObject(body);
        Integer status = (Integer) jsonObject.get("status");
        if (null != status && -2 != status) {
            return true;
        } else {
            return false;
        }
    }

    public static void main(String[] args) {
        String token = getToken("yingzhong", "SXyz@032025.");
//        String data = getDataTemplate(token, "硬件设备");
//        System.out.println(data);
//        SignInfo signInfo = getSign(token, "88.550.1407010088/hardware_yz_202503240001");
//        System.out.println(signInfo);
    }
}
